Amount class

Constructors

Amount({required String type, required double value, required double maximumFee, required double minimumFee})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximumFee ↔ double
getter/setter pair
minimumFee ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair
value ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited