Reference class

Constructors

Reference({String? acquirer, String? gateway, String? order, String? payment, String? track, String? transaction, String? gosellID})

Properties

acquirer ↔ String?
getter/setter pair
gateway ↔ String?
getter/setter pair
gosellID ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
order ↔ String?
getter/setter pair
payment ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
track ↔ String?
getter/setter pair
transaction ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited